library(caret) #machine learinign workflow
library(leaps) #library for stepwise regression
library(MASS) #contains some important linear regression tools
library(caTools) #sample split is from this package
library(tidyverse) #helps us to write concise code

#importing the data
dataset <-  read_delim('Cao2015_SI.csv',
                         delim = ",",
                         col_names = TRUE,
                         trim_ws = TRUE) %>%
  drop_na()

dataset2 <- dataset %>%
  dplyr::select(-c(cid, compound, smiles, RT))

#obeserve the correlation between variables
correlationMatrix <- cor(dataset2, use = "complete.obs")
# find attributes that are highly corrected (ideally >0.75)
highlyCorrelated <- findCorrelation(correlationMatrix, cutoff=0.75)

dataset <- dataset2 %>%
  dplyr::select(-highlyCorrelated) %>%
  dplyr::mutate(RT = dataset$RT)

#preparing the trainign and test set with 80/20 ratio
set.seed(123)
split <- sample.split(dataset$RT, SplitRatio = 0.8)

#splitting the data into two datasets
model_development <- subset(dataset, split == TRUE) 
validation <- subset(dataset, split == FALSE) 

#Trainign the model with cross-validation
#setting the cross-validation parameters
fitControl <- trainControl(## 10-fold CV
  method = "repeatedcv",
  number = 5, #e.g. we have 5 sests, each 20% that act as test sets for choosing the optimal parameters
  repeats = 5) #and we run the cycle 5 times with different splits

#actual training
set.seed(825)
regressor <- train(RT ~ ., 
                   data = model_development, 
                   method = "glmStepAIC", 
                   trControl = fitControl,
                   verbose = FALSE)

print(regressor)
summary(regressor)
regressor$finalModel

#predict tR for the model development set
model_development <- model_development %>%
  mutate(tR_pred = predict(regressor, newdata = model_development))
RMSE(model_development$tR_pred, model_development$RT)
#2.1 min

#predict tR for the validation set
validation <- validation %>%
  mutate(tR_pred = predict(regressor, newdata = validation))
RMSE(validation$tR_pred, validation$RT)
#2.4 min

#plot the data for both model developemnt and validatio
ggplot() +
  geom_point(mapping = aes(x = model_development$RT, y =model_development$tR_pred), color = "blue", size = 2, alpha = 0.25) +
  geom_point(mapping = aes(x = validation$RT, y = validation$tR_pred), color = "red", size = 3, alpha = 0.5) +
  theme_bw()

